@@ -1,5 +1,14 @@
+from __future__ import annotations
+
+from typing import TYPE_CHECKING
+
 from django import forms
 
+if TYPE_CHECKING:
+    from django.contrib.sites.models import Site
+
+__all__ = ["SiteModelFormMixin"]
+
 
 class SiteModelFormMixin:
 
@@ -19,16 +28,16 @@ class SiteModelFormMixin:
 
     def clean(self) -> dict:
         cleaned_data = super().clean()
-        self.validate_with_current_site(cleaned_data)
+        self.validate_with_current_site()
         return cleaned_data
 
-    def validate_with_current_site(self, cleaned_data: dict) -> None:
-        currrent_site = getattr(self, "currrent_site", None)
-        if (
-            currrent_site
-            and cleaned_data.get("site")
-            and currrent_site.id != cleaned_data.get("site").id
-        ):
+    @property
+    def site(self) -> Site:
+        return self.cleaned_data.get("site") or self.instance.site or self.related_visit.site
+
+    def validate_with_current_site(self) -> None:
+        current_site = getattr(self, "current_site", None)
+        if current_site and self.site and current_site.id != self.site.id:
             raise forms.ValidationError(
                 {
                     "site": (
