@@ -1,12 +1,12 @@
 from django.db import models
 
-from ..models import CurrentSiteManager, SiteModelMixin
+from edc_sites.managers import CurrentSiteManager
+from edc_sites.model_mixins import SiteModelMixin
 
 
 class TestModelWithSite(SiteModelMixin, models.Model):
-
     f1 = models.CharField(max_length=10, default="1")
 
-    on_site = CurrentSiteManager()
-
     objects = models.Manager()
+
+    on_site = CurrentSiteManager()
